# Earth's Utilities

Detailed documentation on the `earthstat.utils` module, a collection of functions designed usually used through building the EarthStat library. 


## Utilities Overview
::: earthstat.utils